SHLIB      = libg++.sl
BUILD_LIBS = $(ARLIB) $(SHLIB)
SHFLAGS    = $(LIBCFLAGS)
